summaryrefslogtreecommitdiffstats
path: root/akregator/src/listtabwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/listtabwidget.h')
-rw-r--r--akregator/src/listtabwidget.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/akregator/src/listtabwidget.h b/akregator/src/listtabwidget.h
index 86c14891..f720d36f 100644
--- a/akregator/src/listtabwidget.h
+++ b/akregator/src/listtabwidget.h
@@ -18,8 +18,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef AKREGATOR_LISTTABWIDGET_H
@@ -42,14 +42,15 @@ class TreeNode;
@author Frank Osterfeld
*/
-class ListTabWidget : public QWidget
+class ListTabWidget : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
- ListTabWidget(TQWidget* parent=0, const char* name=0);
+ ListTabWidget(TQWidget* tqparent=0, const char* name=0);
virtual ~ListTabWidget();
enum ViewMode { single, /* horizontalTabs, */ verticalTabs };
@@ -71,7 +72,7 @@ public slots:
void slotItemBegin();
/** select last item in the list */
void slotItemEnd();
/** go to parent item */
void slotItemLeft();
/** go to first child */
void slotItemRight();
@@ -71,7 +72,7 @@ public slots:
/** select last item in the list */
void slotItemEnd();
- /** go to parent item */
+ /** go to tqparent item */
void slotItemLeft();
/** go to first child */